"""
Simple tool for checking a bunch of Nextcloud servers, whether their Nextcloud version is supported and up2date.

 Author: wh0ami
License: MIT License <https://opensource.org/license/MIT>
Project: https://codeberg.org/wh0ami/NextcloudVersionChecker
"""

import json
import urllib.request
import urllib.response

import semver

from nextcloud_version_checker.nextcloud.versioning import nextcloud_version_to_semver


def fetch_current_nextcloud_instance_version(url: str) -> semver.Version:
    """
    Fetch the current version of a Nextcloud instance.

    :param url: URL of the Nextcloud, whose version should be fetched.
    :return: Requested Nextcloud version as semver object.
    """
    status_endpoint_url = f"{url}/status.php"

    http_request = urllib.request.Request(  # noqa: S310
        method="GET",
        url=status_endpoint_url,
        headers={"User-Agent": "Nextcloud-Version-Checker/1.0"},
    )

    with urllib.request.urlopen(url=http_request, timeout=10) as http_response:  # noqa: S310
        version_string = json.loads(http_response.read().decode("utf-8"))["version"]

    return nextcloud_version_to_semver(version_string=version_string)
