"""
Simple tool for checking a bunch of Nextcloud servers, whether their Nextcloud version is supported and up2date.

 Author: wh0ami
License: MIT License <https://opensource.org/license/MIT>
Project: https://codeberg.org/wh0ami/NextcloudVersionChecker
"""

import urllib.request
import urllib.response

import xmltodict

from nextcloud_version_checker.nextcloud.versioning import nextcloud_version_to_semver


def fetch_major_version_information(major_version: int) -> dict:
    """
    Request information about a specific major version from the updater server.

    :param major_version: Major version, whose information should be fetched.
    :return: Dict of information
    """
    http_request = urllib.request.Request(
        method="GET",
        url=f"https://updates.nextcloud.com/updater_server/?version={major_version}x0x0x0xxxstablexxx999x0x0",
    )

    with urllib.request.urlopen(url=http_request, timeout=10) as http_response:  # noqa: S310
        major_version_information = xmltodict.parse(
            xml_input=http_response.read().decode("utf-8"),
        )["nextcloud"]

    return {
        "is_eol": bool(major_version_information["eol"] == "1"),
        "latest_version": nextcloud_version_to_semver(version_string=major_version_information["version"]),
    }
